from AccessControl import ClassSecurityInfo
from Products.Archetypes.Registry import registerField
from Products.Archetypes.Field import Image, ImageField
from Products.ATContentTypes.lib.imagetransform import ATCTImageTransform
from StringIO import StringIO
from cgi import escape
import exif
import base64

class FancyImage(Image):

    security  = ClassSecurityInfo()

    def getEXIF(self, data):
        data_file = StringIO(data)
        
        try:
            result = exif.process_file(data_file, debug=False)
        except ValueError:
            result = None
            
        return result

    security.declarePublic('getEXIFString')
    def getEXIFString(self):
        'Return EXIF data as String'

        if self.exif_data is None:
            return None
        
        exif_keys = ['EXIF ApertureValue', 'EXIF ExposureTime',
                     'EXIF ShutterSpeedValue', 'Image Make',
                     'Image Model', 'MakerNote DigitalZoom',
                     'MakerNote EasyShootingMode',
                     'MakerNote ExposureMode', 'MakerNote FlashActivity',
                     'MakerNote FlashBias', 'MakerNote FlashDetails',
                     'MakerNote FlashMode', 'MakerNote FocusMode',
                     'MakerNote FocusType', 'MakerNote Quality',
                     'MakerNote Saturation', 'MakerNote SubjectDistance']

        exif_string = ''
        
        for key in exif_keys:
            if self.exif_data.has_key(key):
                exif_string = exif_string + key + ': ' + str(self.exif_data[key]) + '\n'
                
        exif_string = exif_string[:-6]
	exif_string = escape(exif_string)
	exif_string = exif_string.replace('\n', '<br />')

        return exif_string

    def update_data(self, data, content_type=None, size=None):
        result = Image.update_data(self, data, content_type, size)
        self.exif_data = self.getEXIF(data)
        return result


class FancyImageField(ImageField):

    _properties = ImageField._properties.copy()
    _properties.update({
        'content_class': FancyImage,
	'sizes' : {'thumb': (300, 300)}
        })

    security  = ClassSecurityInfo()

    def flexdb_export(self, instance):
        return base64.encodestring(str(self.getRaw(instance).data))

    def flexdb_import(self, instance, value):
        self.set(instance, base64.decodestring(value))

    def flexdb_get_thumb(self, instance):
        return self.getScale(instance, 'thumb')

    def flexdb_get_thumb_name(self):
        return self.getName() + '_thumb'

    def flexdb_thumb_tag(self, instance, caller_context, **kwargs):
        result = '<img src="%(src)s" />'
        result = result % {'src': self.get_relative_path_string(caller_context, instance)}
        return result
        
registerField(FancyImageField,
              title='FancyImage',
              description=('Used for storing images. '
                           'Images can then be retrieved in '
                           'different thumbnail sizes'))

