# -*- coding: utf-8 -*-

####################################################################
# FlexDB
# Guenther Starnberger <gst@sysfrog.org>
####################################################################

# Python / Zope ####################################################
from AccessControl import  ClassSecurityInfo
####################################################################

# Plone / Archetypes ###############################################
from Products.Archetypes.public import BaseSchema, Schema
from Products.Archetypes.public import BaseContent, registerType
from Products.Archetypes.public import TextField, RichWidget
from Products.Archetypes.Marshall import PrimaryFieldMarshaller
from Products.ATSchemaEditorNG.ParentManagedSchema import ParentManagedSchema
####################################################################

# FlexDB ###########################################################
import config
from Products.FlexDB.FancyImageField import FancyImageField
####################################################################

class FlexDBItem(ParentManagedSchema, BaseContent):
    '''This is a FlexDBItem which can be created inside FlexDB'''

    # The is basically a plain Archetypes class. The schema of this
    # class is managed by the parent folder and the functionality is
    # provided by Archetypes.

    __implements__ = (ParentManagedSchema.__implements__, BaseContent.__implements__)

    meta_type = portal_type = 'FlexDBItem'

    security = ClassSecurityInfo()

    # Factory Type Information
    global_allow = False

    content_icon = 'flexdb_item_icon.gif'

    # Exclude items of this type from the navigation
    exclude_from_nav = True

    # Automatically generate a short name
    _at_rename_after_creation = True

    # This is the initial schema. Modifications are stored by the
    # parent (in the sense of Aquisition) SchemaEditor class.

    schema = BaseSchema.copy() +  Schema((
        TextField('body',
                  searchable = True,
                  required = True,
                  primary = True,
                  widget=RichWidget(label = 'Body'),
                  ),
        ),
        marshall = PrimaryFieldMarshaller(),
    )
    
    schema['id'].widget.visible.update({'list': 'invisible'})

    security.declarePrivate('manage_afterAdd')
    def manage_afterAdd(self, item, container):
        self.updateSchemaFromEditor()
        BaseContent.manage_afterAdd(self, item, container)

    security.declarePublic('webui_export')
    def webui_export(self, current_context, original_context, zip):
        'export in webui format'

        # to avoid redundancy this method is also called by
        # FlexDBCategory using Acquisition, therefore current_context
        # must be used instead of self.

        self_relative_path = self.get_relative_path(original_context, current_context)

        self_zip_path = self.relative_path_to_string(self_relative_path + ('index.html',))

        zip.writestr(self_zip_path, str(self.flexdb_webui_item(context = current_context,
                                                               original_context = original_context)))

        
        for field in self.get_schema_fields():
            if type(field) == FancyImageField:
                self_zip_path = self.relative_path_to_string(self_relative_path + (field.flexdb_get_thumb_name(),))
                zip.writestr(self_zip_path, str(field.flexdb_get_thumb(self).data))
                
        return None

    security.declarePrivate('flexdb_lookup_provider')
    def flexdb_lookup_provider(self):
        'Just a category - some parent provides the Schema'
        return self.aq_parent.flexdb_lookup_provider()

    security.declarePrivate('lookup_provider')
    def lookup_provider(self):
        'Return schema provider instance'
        return self.flexdb_lookup_provider()

registerType(FlexDBItem, config.PROJECTNAME)
