# -*- coding: utf-8 -*-

# FlexDB Configuration
# Guenther Starnberger <gst@sysfrog.org>

from Products.CMFCore.permissions import AddPortalContent
from Products.CMFCore import CMFCorePermissions
from Products.Archetypes.Field import *
from Products.Archetypes.Widget import *
from Products.Archetypes.Storage import *

from URLWidget import URLWidget
from CheckBoxWidget import CheckBoxWidget
from ObjLinkWidget import ObjLinkWidget
from TruncatableStringWidget import TruncatableStringWidget
from FancyImageWidget import FancyImageWidget

from FancyImageField import FancyImageField

ADD_CONTENT_PERMISSION = AddPortalContent
PROJECTNAME = 'FlexDB'
SKINS_DIR = 'skins'

GLOBALS = globals()

SCHEMA_ID = 'FlexDB'
UNDELETEABLE_FIELDS = ('title', 'description', 'solution', 'classification', 'topic', 'importance', 'contact_email', 'contact_name')

add_permission = CMFCorePermissions.AddPortalContent
edit_permission = CMFCorePermissions.ModifyPortalContent
view_permission = CMFCorePermissions.View
from Products.ATSchemaEditorNG.config import ManageSchemaPermission

truncatable_string_len = 100

ADD_TYPE_MAP = {
    'FancyImageField':      FancyImageField,
    'TextField':       TextField,
    }

FIELD_INFO = ('StringField',
              'IntegerField',
              'FloatField',
              'FixedPointField',
              'LinesField',
              'DateTimeField',
              'BooleanField',
              'ReferenceField',
              'ComputedField',
              'ImageField',
              'TextField')

FIELD_REGISTRY_INFO = (
    ('StringField',      {'field': StringField}),
    ('IntegerField',     {'field': IntegerField}),
    ('FloatField',       {'field': FloatField}),
    ('TextField',        {'field': TextField,
                          'post_macro': 'here/textfield_postmacro/macros/field_params',
                          'post_method': 'atse_textFieldPostMethod'}),
    ('FixedPointField',  {'field': FixedPointField}),
    ('LinesField',       {'field': LinesField}),
    ('DateTimeField',    {'field': DateTimeField}),
    ('BooleanField',     {'field': BooleanField}),
    ('ReferenceField',   {'field': ReferenceField}),
    ('ComputedField',    {'field': ComputedField, 'useStorage': False,
                          'post_macro': 'here/computedfield_postmacro/macros/expression',
                          'post_method': 'atse_computedFieldPostMethod'}),
    ('ImageField',       {'field': ImageField}),
    ('FancyImageField',       {'field': FancyImageField}),
    )

WIDGET_REGISTRY_INFO = (
    ('String',      {'widget':StringWidget(), 'visible':True, 'useVocab':False}),
    ('Textarea',    {'widget':TextAreaWidget(), 'visible':True, 'useVocab':False,
                     'size_macro':'here/atse_macros/macros/row_col_size'}),
    ('Radio',       {'widget':SelectionWidget(format='radio'), 'visible':True,
                     'useVocab':True}),
    ('Select',      {'widget':SelectionWidget(format='select'), 'visible':True,
                     'useVocab':True}),
    ('Flex',        {'widget':SelectionWidget(format='flex'), 'visible':True,
                     'useVocab':True, 'size_macro':'here/atse_macros/macros/row_col_size'}),
    ('Lines',       {'widget':LinesWidget(), 'visible':True, 'useVocab':False}),
    ('Calendar',    {'widget':CalendarWidget(), 'visible':True, 'useVocab':False}),
    ('Boolean',     {'widget':BooleanWidget(), 'visible':True, 'useVocab':False}),
    ('MultiSelect', {'widget':MultiSelectionWidget(), 'visible':True, 'useVocab':True}),
    ('Richtext',    {'widget':RichWidget(), 'visible':True, 'useVocab':False}),
    ('Password',    {'widget':PasswordWidget(), 'visible':True, 'useVocab':False}),
    ('Visual',      {'widget':VisualWidget(), 'visible':True, 'useVocab':False}),
    ('Epoz',        {'widget':EpozWidget(), 'visible':True, 'useVocab':False}),
    ('Picklist',    {'widget':PicklistWidget(), 'visible':True, 'useVocab':True}),
    ('InAndOut',    {'widget':InAndOutWidget(), 'visible':True, 'useVocab':True}),
    ('Image',       {'widget':ImageWidget(), 'visible':True, 'useVocab':False}),
    ('Integer',     {'widget':IntegerWidget(), 'visible':False, 'useVocab':False}),
    ('Decimal',     {'widget':DecimalWidget(), 'visible':False, 'useVocab':False}),
    ('Keywords',    {'widget':KeywordWidget(), 'visible':False, 'useVocab':False}),
    ('Reference',   {'widget':ReferenceWidget(), 'visible':False, 'useVocab':False}),
    ('Computed',    {'widget':ComputedWidget()}),
    ('URL',         {'widget':URLWidget(), 'visible':True, 'useVocab':False}),
    ('CheckBox',    {'widget':CheckBoxWidget(), 'visible':True, 'useVocab':False}),
    ('ObjLink',     {'widget':ObjLinkWidget(), 'visible':True, 'useVocab':False}),
    ('Rich',    {'widget':RichWidget(), 'visible':True, 'useVocab':False}),
    ('TruncatableString',      {'widget':TruncatableStringWidget(), 'visible':True, 'useVocab':False}),
    ('FancyImage',       {'widget':FancyImageWidget(), 'visible':True, 'useVocab':False}),
    )

STORAGE_REGISTRY_INFO = (
    ('Attribute', {'storage':AttributeStorage(), 'visible':True}),
    )


# This defines the SchemaEditor to FlexDB mappings

FLEXDB_TYPES = { 'String': { 'type': 'StringField',
                             'widget': 'String',
                             'storage': 'Attribute' },
                 'RichText': { 'type': 'TextField',
                               'widget': 'Rich',
                               'storage': 'Attribute' },
                 'Image': { 'type': 'FancyImageField',
                            'widget': 'FancyImage',
                            'storage': 'Attribute' },
                 'DateTime': { 'type': 'DateTimeField',
                               'widget': 'Calendar',
                               'storage': 'Attribute' },
                 'CheckBox': { 'type': 'BooleanField',
                               'widget': 'CheckBox',
                               'storage': 'Attribute'},
                 'URL': { 'type': 'StringField',
                          'widget': 'URL',
                          'storage': 'Attribute'},
                 'ObjLink': { 'type': 'StringField',
                              'widget': 'ObjLink',
                              'storage': 'Attribute'},
                 'TruncatableString': { 'type': 'StringField',
                                        'widget': 'TruncatableString',
                                        'storage': 'Attribute'},
                 }


